entities/rest_response library

Classes

RestResponse<T>
This is the class that will be returned when a call is made to the REST API. It is typed with the data that will be returned. In case of an error, it will return a RestException in the exception field.

Exceptions / Errors

RestException
This class implements an Exception and gets all the information from the DioException if there is a failure at the endpoint.