RestException class

This class implements an Exception and gets all the information from the DioException if there is a failure at the endpoint.

Implemented types

Constructors

RestException({String? message, dynamic dataResponse, StackTrace? stackTrace})

Properties

dataResponse → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited