RestResponse<T> class
This is the class that will be returned when a call is made to the REST API. It is typed with the data that will be returned. In case of an error, it will return a RestException in the exception field.
Constructors
- RestResponse(RestStatusCode restStatusCode)
Properties
- data ↔ T
-
getter/setter pair
- exception ↔ RestException?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- restStatusCode → RestStatusCode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
no setter
- success → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited