AuthInterceptor class
This interceptor is used to authenticate requests.
The getToken parameter is a function that returns the token for authentication. isBearerPrefixToken indicates whether the authentication header is the Bearer token by default (default true). If it is not, you must indicate the header in authHeaderParameter.
If refreshToken is passed, it will be executed after receiving a 401 from the REST API.
Constructors
Properties
- authHeaderParameter → String?
-
final
-
getToken
→ Future<
String> Function() -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBearerPrefixToken → bool
-
final
-
refreshToken
→ Future<
void> Function()? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → void - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → Future - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void - Called when the response is about to be resolved.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited